..
    Copyright (C) 2024 CERN.

    Invenio-Preservation-Sync is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.

Changes
=======

Version 0.2.0 (released 2025-03-10)

- installation: upgrade invenio dependencies

Version 0.1.1 (released 2024-12-04)

 - schema: optional fields can be None

Version 0.1.0 (released 2024-11-13)

- ui: added utils function to render as an External resource
- Initial public release.
